from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Emitter:
	"""Emitter commands group definition. 29 total commands, 1 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("emitter", core, parent)

	@property
	def mode(self):
		"""mode commands group. 4 Sub-classes, 5 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._cmd_group)
		return self._mode

	def get_catalog(self) -> str:
		"""SCPI: EMITter:CATalog \n
		Snippet: value: str = driver.emitter.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('EMITter:CATalog?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: EMITter:COMMent \n
		Snippet: value: str = driver.emitter.get_comment() \n
		No command help available \n
			:return: comment: No help available
		"""
		response = self._core.io.query_str('EMITter:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: EMITter:COMMent \n
		Snippet: driver.emitter.set_comment(comment = '1') \n
		No command help available \n
			:param comment: No help available
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'EMITter:COMMent {param}')

	def set_create(self, create: str) -> None:
		"""SCPI: EMITter:CREate \n
		Snippet: driver.emitter.set_create(create = '1') \n
		No command help available \n
			:param create: No help available
		"""
		param = Conversions.value_to_quoted_str(create)
		self._core.io.write(f'EMITter:CREate {param}')

	def get_eirp(self) -> float:
		"""SCPI: EMITter:EIRP \n
		Snippet: value: float = driver.emitter.get_eirp() \n
		No command help available \n
			:return: eirp: No help available
		"""
		response = self._core.io.query_str('EMITter:EIRP?')
		return Conversions.str_to_float(response)

	def set_eirp(self, eirp: float) -> None:
		"""SCPI: EMITter:EIRP \n
		Snippet: driver.emitter.set_eirp(eirp = 1.0) \n
		No command help available \n
			:param eirp: No help available
		"""
		param = Conversions.decimal_value_to_str(eirp)
		self._core.io.write(f'EMITter:EIRP {param}')

	def get_frequency(self) -> float:
		"""SCPI: EMITter:FREQuency \n
		Snippet: value: float = driver.emitter.get_frequency() \n
		No command help available \n
			:return: frequency: No help available
		"""
		response = self._core.io.query_str('EMITter:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: EMITter:FREQuency \n
		Snippet: driver.emitter.set_frequency(frequency = 1.0) \n
		No command help available \n
			:param frequency: No help available
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'EMITter:FREQuency {param}')

	def get_name(self) -> str:
		"""SCPI: EMITter:NAME \n
		Snippet: value: str = driver.emitter.get_name() \n
		No command help available \n
			:return: name: No help available
		"""
		response = self._core.io.query_str('EMITter:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: EMITter:NAME \n
		Snippet: driver.emitter.set_name(name = '1') \n
		No command help available \n
			:param name: No help available
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'EMITter:NAME {param}')

	def set_remove(self, remove: str) -> None:
		"""SCPI: EMITter:REMove \n
		Snippet: driver.emitter.set_remove(remove = '1') \n
		No command help available \n
			:param remove: No help available
		"""
		param = Conversions.value_to_quoted_str(remove)
		self._core.io.write(f'EMITter:REMove {param}')

	def get_select(self) -> str:
		"""SCPI: EMITter:SELect \n
		Snippet: value: str = driver.emitter.get_select() \n
		No command help available \n
			:return: select: No help available
		"""
		response = self._core.io.query_str('EMITter:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: EMITter:SELect \n
		Snippet: driver.emitter.set_select(select = '1') \n
		No command help available \n
			:param select: No help available
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'EMITter:SELect {param}')

	def clone(self) -> 'Emitter':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Emitter(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
