from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Instrument:
	"""Instrument commands group definition. 19 total commands, 1 Subgroups, 18 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("instrument", core, parent)

	@property
	def adb(self):
		"""adb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adb'):
			from .Adb import Adb
			self._adb = Adb(self._core, self._cmd_group)
		return self._adb

	def set_add(self, add: str) -> None:
		"""SCPI: INSTrument:ADD \n
		Snippet: driver.instrument.set_add(add = '1') \n
		No command help available \n
			:param add: No help available
		"""
		param = Conversions.value_to_quoted_str(add)
		self._core.io.write(f'INSTrument:ADD {param}')

	def get_capabilities(self) -> str:
		"""SCPI: INSTrument:CAPabilities \n
		Snippet: value: str = driver.instrument.get_capabilities() \n
		No command help available \n
			:return: capabilities: No help available
		"""
		response = self._core.io.query_str('INSTrument:CAPabilities?')
		return trim_str_response(response)

	def set_capabilities(self, capabilities: str) -> None:
		"""SCPI: INSTrument:CAPabilities \n
		Snippet: driver.instrument.set_capabilities(capabilities = '1') \n
		No command help available \n
			:param capabilities: No help available
		"""
		param = Conversions.value_to_quoted_str(capabilities)
		self._core.io.write(f'INSTrument:CAPabilities {param}')

	def clear(self) -> None:
		"""SCPI: INSTrument:CLEar \n
		Snippet: driver.instrument.clear() \n
		No command help available \n
		"""
		self._core.io.write(f'INSTrument:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INSTrument:CLEar \n
		Snippet: driver.instrument.clear_with_opc() \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INSTrument:CLEar', opc_timeout_ms)

	def get_comment(self) -> str:
		"""SCPI: INSTrument:COMMent \n
		Snippet: value: str = driver.instrument.get_comment() \n
		No command help available \n
			:return: comment: No help available
		"""
		response = self._core.io.query_str('INSTrument:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: INSTrument:COMMent \n
		Snippet: driver.instrument.set_comment(comment = '1') \n
		No command help available \n
			:param comment: No help available
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'INSTrument:COMMent {param}')

	def set_connect(self, connect: str) -> None:
		"""SCPI: INSTrument:CONNect \n
		Snippet: driver.instrument.set_connect(connect = '1') \n
		No command help available \n
			:param connect: No help available
		"""
		param = Conversions.value_to_quoted_str(connect)
		self._core.io.write(f'INSTrument:CONNect {param}')

	def get_count(self) -> float:
		"""SCPI: INSTrument:COUNt \n
		Snippet: value: float = driver.instrument.get_count() \n
		No command help available \n
			:return: count: No help available
		"""
		response = self._core.io.query_str('INSTrument:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: INSTrument:DELete \n
		Snippet: driver.instrument.delete(delete = 1.0) \n
		No command help available \n
			:param delete: No help available
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'INSTrument:DELete {param}')

	def get_firmware(self) -> str:
		"""SCPI: INSTrument:FIRMware \n
		Snippet: value: str = driver.instrument.get_firmware() \n
		No command help available \n
			:return: firmware: No help available
		"""
		response = self._core.io.query_str('INSTrument:FIRMware?')
		return trim_str_response(response)

	def get_list_py(self) -> List[int]:
		"""SCPI: INSTrument:LIST \n
		Snippet: value: List[int] = driver.instrument.get_list_py() \n
		No command help available \n
			:return: list_py: No help available
		"""
		response = self._core.io.query_bin_or_ascii_int_list('INSTrument:LIST?')
		return response

	def get_name(self) -> str:
		"""SCPI: INSTrument:NAME \n
		Snippet: value: str = driver.instrument.get_name() \n
		No command help available \n
			:return: name: No help available
		"""
		response = self._core.io.query_str('INSTrument:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: INSTrument:NAME \n
		Snippet: driver.instrument.set_name(name = '1') \n
		No command help available \n
			:param name: No help available
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'INSTrument:NAME {param}')

	def get_online(self) -> float:
		"""SCPI: INSTrument:ONLine \n
		Snippet: value: float = driver.instrument.get_online() \n
		No command help available \n
			:return: online: No help available
		"""
		response = self._core.io.query_str('INSTrument:ONLine?')
		return Conversions.str_to_float(response)

	def set_online(self, online: float) -> None:
		"""SCPI: INSTrument:ONLine \n
		Snippet: driver.instrument.set_online(online = 1.0) \n
		No command help available \n
			:param online: No help available
		"""
		param = Conversions.decimal_value_to_str(online)
		self._core.io.write(f'INSTrument:ONLine {param}')

	# noinspection PyTypeChecker
	def get_pmod(self) -> enums.PmodSource:
		"""SCPI: INSTrument:PMOD \n
		Snippet: value: enums.PmodSource = driver.instrument.get_pmod() \n
		No command help available \n
			:return: pmod: No help available
		"""
		response = self._core.io.query_str('INSTrument:PMOD?')
		return Conversions.str_to_scalar_enum(response, enums.PmodSource)

	def set_pmod(self, pmod: enums.PmodSource) -> None:
		"""SCPI: INSTrument:PMOD \n
		Snippet: driver.instrument.set_pmod(pmod = enums.PmodSource.EXTernal) \n
		No command help available \n
			:param pmod: No help available
		"""
		param = Conversions.enum_scalar_to_str(pmod, enums.PmodSource)
		self._core.io.write(f'INSTrument:PMOD {param}')

	# noinspection PyTypeChecker
	def get_psec(self) -> enums.Psec:
		"""SCPI: INSTrument:PSEC \n
		Snippet: value: enums.Psec = driver.instrument.get_psec() \n
		No command help available \n
			:return: psec: No help available
		"""
		response = self._core.io.query_str('INSTrument:PSEC?')
		return Conversions.str_to_scalar_enum(response, enums.Psec)

	def set_psec(self, psec: enums.Psec) -> None:
		"""SCPI: INSTrument:PSEC \n
		Snippet: driver.instrument.set_psec(psec = enums.Psec.NONE) \n
		No command help available \n
			:param psec: No help available
		"""
		param = Conversions.enum_scalar_to_str(psec, enums.Psec)
		self._core.io.write(f'INSTrument:PSEC {param}')

	def get_resource(self) -> str:
		"""SCPI: INSTrument:RESource \n
		Snippet: value: str = driver.instrument.get_resource() \n
		No command help available \n
			:return: resource: No help available
		"""
		response = self._core.io.query_str('INSTrument:RESource?')
		return trim_str_response(response)

	def get_select(self) -> float:
		"""SCPI: INSTrument:SELect \n
		Snippet: value: float = driver.instrument.get_select() \n
		No command help available \n
			:return: select: No help available
		"""
		response = self._core.io.query_str('INSTrument:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: INSTrument:SELect \n
		Snippet: driver.instrument.set_select(select = 1.0) \n
		No command help available \n
			:param select: No help available
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'INSTrument:SELect {param}')

	def get_supported(self) -> float:
		"""SCPI: INSTrument:SUPPorted \n
		Snippet: value: float = driver.instrument.get_supported() \n
		No command help available \n
			:return: supported: No help available
		"""
		response = self._core.io.query_str('INSTrument:SUPPorted?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.GeneratorType:
		"""SCPI: INSTrument:TYPE \n
		Snippet: value: enums.GeneratorType = driver.instrument.get_type_py() \n
		No command help available \n
			:return: type_py: No help available
		"""
		response = self._core.io.query_str('INSTrument:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorType)

	def set_type_py(self, type_py: enums.GeneratorType) -> None:
		"""SCPI: INSTrument:TYPE \n
		Snippet: driver.instrument.set_type_py(type_py = enums.GeneratorType.SGT) \n
		No command help available \n
			:param type_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.GeneratorType)
		self._core.io.write(f'INSTrument:TYPE {param}')

	def get_virtual(self) -> bool:
		"""SCPI: INSTrument:VIRTual \n
		Snippet: value: bool = driver.instrument.get_virtual() \n
		No command help available \n
			:return: virtual: No help available
		"""
		response = self._core.io.query_str('INSTrument:VIRTual?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'Instrument':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Instrument(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
