from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Movement:
	"""Movement commands group definition. 26 total commands, 2 Subgroups, 23 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("movement", core, parent)

	@property
	def importPy(self):
		"""importPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_importPy'):
			from .ImportPy import ImportPy
			self._importPy = ImportPy(self._core, self._cmd_group)
		return self._importPy

	@property
	def vfile(self):
		"""vfile commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_vfile'):
			from .Vfile import Vfile
			self._vfile = Vfile(self._core, self._cmd_group)
		return self._vfile

	def get_acceleration(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:ACCeleration \n
		Snippet: value: float = driver.scenario.localized.movement.get_acceleration() \n
		No command help available \n
			:return: acceleration: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:ACCeleration?')
		return Conversions.str_to_float(response)

	def set_acceleration(self, acceleration: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:ACCeleration \n
		Snippet: driver.scenario.localized.movement.set_acceleration(acceleration = 1.0) \n
		No command help available \n
			:param acceleration: No help available
		"""
		param = Conversions.decimal_value_to_str(acceleration)
		self._core.io.write(f'SCENario:LOCalized:MOVement:ACCeleration {param}')

	def get_altitude(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:ALTitude \n
		Snippet: value: float = driver.scenario.localized.movement.get_altitude() \n
		No command help available \n
			:return: altitude: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:ALTitude?')
		return Conversions.str_to_float(response)

	def set_altitude(self, altitude: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:ALTitude \n
		Snippet: driver.scenario.localized.movement.set_altitude(altitude = 1.0) \n
		No command help available \n
			:param altitude: No help available
		"""
		param = Conversions.decimal_value_to_str(altitude)
		self._core.io.write(f'SCENario:LOCalized:MOVement:ALTitude {param}')

	def get_angle(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:ANGLe \n
		Snippet: value: float = driver.scenario.localized.movement.get_angle() \n
		No command help available \n
			:return: angle: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:ANGLe?')
		return Conversions.str_to_float(response)

	def set_angle(self, angle: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:ANGLe \n
		Snippet: driver.scenario.localized.movement.set_angle(angle = 1.0) \n
		No command help available \n
			:param angle: No help available
		"""
		param = Conversions.decimal_value_to_str(angle)
		self._core.io.write(f'SCENario:LOCalized:MOVement:ANGLe {param}')

	# noinspection PyTypeChecker
	def get_attitude(self) -> enums.Attitude:
		"""SCPI: SCENario:LOCalized:MOVement:ATTitude \n
		Snippet: value: enums.Attitude = driver.scenario.localized.movement.get_attitude() \n
		No command help available \n
			:return: attitude: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:ATTitude?')
		return Conversions.str_to_scalar_enum(response, enums.Attitude)

	def set_attitude(self, attitude: enums.Attitude) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:ATTitude \n
		Snippet: driver.scenario.localized.movement.set_attitude(attitude = enums.Attitude.CONStant) \n
		No command help available \n
			:param attitude: No help available
		"""
		param = Conversions.enum_scalar_to_str(attitude, enums.Attitude)
		self._core.io.write(f'SCENario:LOCalized:MOVement:ATTitude {param}')

	def get_clatitude(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:CLATitude \n
		Snippet: value: float = driver.scenario.localized.movement.get_clatitude() \n
		No command help available \n
			:return: clatitude: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:CLATitude?')
		return Conversions.str_to_float(response)

	def set_clatitude(self, clatitude: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:CLATitude \n
		Snippet: driver.scenario.localized.movement.set_clatitude(clatitude = 1.0) \n
		No command help available \n
			:param clatitude: No help available
		"""
		param = Conversions.decimal_value_to_str(clatitude)
		self._core.io.write(f'SCENario:LOCalized:MOVement:CLATitude {param}')

	def clear(self) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:CLEar \n
		Snippet: driver.scenario.localized.movement.clear() \n
		No command help available \n
		"""
		self._core.io.write(f'SCENario:LOCalized:MOVement:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:CLEar \n
		Snippet: driver.scenario.localized.movement.clear_with_opc() \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:LOCalized:MOVement:CLEar', opc_timeout_ms)

	def get_clongitude(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:CLONgitude \n
		Snippet: value: float = driver.scenario.localized.movement.get_clongitude() \n
		No command help available \n
			:return: clongitude: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:CLONgitude?')
		return Conversions.str_to_float(response)

	def set_clongitude(self, clongitude: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:CLONgitude \n
		Snippet: driver.scenario.localized.movement.set_clongitude(clongitude = 1.0) \n
		No command help available \n
			:param clongitude: No help available
		"""
		param = Conversions.decimal_value_to_str(clongitude)
		self._core.io.write(f'SCENario:LOCalized:MOVement:CLONgitude {param}')

	def get_east(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:EAST \n
		Snippet: value: float = driver.scenario.localized.movement.get_east() \n
		No command help available \n
			:return: east: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:EAST?')
		return Conversions.str_to_float(response)

	def set_east(self, east: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:EAST \n
		Snippet: driver.scenario.localized.movement.set_east(east = 1.0) \n
		No command help available \n
			:param east: No help available
		"""
		param = Conversions.decimal_value_to_str(east)
		self._core.io.write(f'SCENario:LOCalized:MOVement:EAST {param}')

	def get_height(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:HEIGht \n
		Snippet: value: float = driver.scenario.localized.movement.get_height() \n
		No command help available \n
			:return: height: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:HEIGht?')
		return Conversions.str_to_float(response)

	def set_height(self, height: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:HEIGht \n
		Snippet: driver.scenario.localized.movement.set_height(height = 1.0) \n
		No command help available \n
			:param height: No help available
		"""
		param = Conversions.decimal_value_to_str(height)
		self._core.io.write(f'SCENario:LOCalized:MOVement:HEIGht {param}')

	def get_latitude(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:LATitude \n
		Snippet: value: float = driver.scenario.localized.movement.get_latitude() \n
		No command help available \n
			:return: latitude: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:LATitude?')
		return Conversions.str_to_float(response)

	def set_latitude(self, latitude: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:LATitude \n
		Snippet: driver.scenario.localized.movement.set_latitude(latitude = 1.0) \n
		No command help available \n
			:param latitude: No help available
		"""
		param = Conversions.decimal_value_to_str(latitude)
		self._core.io.write(f'SCENario:LOCalized:MOVement:LATitude {param}')

	def get_longitude(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:LONGitude \n
		Snippet: value: float = driver.scenario.localized.movement.get_longitude() \n
		No command help available \n
			:return: longitude: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:LONGitude?')
		return Conversions.str_to_float(response)

	def set_longitude(self, longitude: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:LONGitude \n
		Snippet: driver.scenario.localized.movement.set_longitude(longitude = 1.0) \n
		No command help available \n
			:param longitude: No help available
		"""
		param = Conversions.decimal_value_to_str(longitude)
		self._core.io.write(f'SCENario:LOCalized:MOVement:LONGitude {param}')

	def get_north(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:NORTh \n
		Snippet: value: float = driver.scenario.localized.movement.get_north() \n
		No command help available \n
			:return: north: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:NORTh?')
		return Conversions.str_to_float(response)

	def set_north(self, north: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:NORTh \n
		Snippet: driver.scenario.localized.movement.set_north(north = 1.0) \n
		No command help available \n
			:param north: No help available
		"""
		param = Conversions.decimal_value_to_str(north)
		self._core.io.write(f'SCENario:LOCalized:MOVement:NORTh {param}')

	def get_pitch(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:PITCh \n
		Snippet: value: float = driver.scenario.localized.movement.get_pitch() \n
		No command help available \n
			:return: pitch: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:PITCh?')
		return Conversions.str_to_float(response)

	def set_pitch(self, pitch: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:PITCh \n
		Snippet: driver.scenario.localized.movement.set_pitch(pitch = 1.0) \n
		No command help available \n
			:param pitch: No help available
		"""
		param = Conversions.decimal_value_to_str(pitch)
		self._core.io.write(f'SCENario:LOCalized:MOVement:PITCh {param}')

	# noinspection PyTypeChecker
	def get_rframe(self) -> enums.MovementRframe:
		"""SCPI: SCENario:LOCalized:MOVement:RFRame \n
		Snippet: value: enums.MovementRframe = driver.scenario.localized.movement.get_rframe() \n
		No command help available \n
			:return: rframe: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:RFRame?')
		return Conversions.str_to_scalar_enum(response, enums.MovementRframe)

	def set_rframe(self, rframe: enums.MovementRframe) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:RFRame \n
		Snippet: driver.scenario.localized.movement.set_rframe(rframe = enums.MovementRframe.PZ) \n
		No command help available \n
			:param rframe: No help available
		"""
		param = Conversions.enum_scalar_to_str(rframe, enums.MovementRframe)
		self._core.io.write(f'SCENario:LOCalized:MOVement:RFRame {param}')

	# noinspection PyTypeChecker
	def get_rmode(self) -> enums.MovementRmode:
		"""SCPI: SCENario:LOCalized:MOVement:RMODe \n
		Snippet: value: enums.MovementRmode = driver.scenario.localized.movement.get_rmode() \n
		No command help available \n
			:return: rmode: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:RMODe?')
		return Conversions.str_to_scalar_enum(response, enums.MovementRmode)

	def set_rmode(self, rmode: enums.MovementRmode) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:RMODe \n
		Snippet: driver.scenario.localized.movement.set_rmode(rmode = enums.MovementRmode.CYCLic) \n
		No command help available \n
			:param rmode: No help available
		"""
		param = Conversions.enum_scalar_to_str(rmode, enums.MovementRmode)
		self._core.io.write(f'SCENario:LOCalized:MOVement:RMODe {param}')

	def get_roll(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:ROLL \n
		Snippet: value: float = driver.scenario.localized.movement.get_roll() \n
		No command help available \n
			:return: roll: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:ROLL?')
		return Conversions.str_to_float(response)

	def set_roll(self, roll: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:ROLL \n
		Snippet: driver.scenario.localized.movement.set_roll(roll = 1.0) \n
		No command help available \n
			:param roll: No help available
		"""
		param = Conversions.decimal_value_to_str(roll)
		self._core.io.write(f'SCENario:LOCalized:MOVement:ROLL {param}')

	def get_smoothening(self) -> bool:
		"""SCPI: SCENario:LOCalized:MOVement:SMOothening \n
		Snippet: value: bool = driver.scenario.localized.movement.get_smoothening() \n
		No command help available \n
			:return: smoothening: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:SMOothening?')
		return Conversions.str_to_bool(response)

	def set_smoothening(self, smoothening: bool) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:SMOothening \n
		Snippet: driver.scenario.localized.movement.set_smoothening(smoothening = False) \n
		No command help available \n
			:param smoothening: No help available
		"""
		param = Conversions.bool_to_str(smoothening)
		self._core.io.write(f'SCENario:LOCalized:MOVement:SMOothening {param}')

	def get_speed(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:SPEed \n
		Snippet: value: float = driver.scenario.localized.movement.get_speed() \n
		No command help available \n
			:return: speed: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:SPEed?')
		return Conversions.str_to_float(response)

	def set_speed(self, speed: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:SPEed \n
		Snippet: driver.scenario.localized.movement.set_speed(speed = 1.0) \n
		No command help available \n
			:param speed: No help available
		"""
		param = Conversions.decimal_value_to_str(speed)
		self._core.io.write(f'SCENario:LOCalized:MOVement:SPEed {param}')

	def get_spinning(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:SPINning \n
		Snippet: value: float = driver.scenario.localized.movement.get_spinning() \n
		No command help available \n
			:return: spinning: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:SPINning?')
		return Conversions.str_to_float(response)

	def set_spinning(self, spinning: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:SPINning \n
		Snippet: driver.scenario.localized.movement.set_spinning(spinning = 1.0) \n
		No command help available \n
			:param spinning: No help available
		"""
		param = Conversions.decimal_value_to_str(spinning)
		self._core.io.write(f'SCENario:LOCalized:MOVement:SPINning {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.MovementType:
		"""SCPI: SCENario:LOCalized:MOVement:TYPE \n
		Snippet: value: enums.MovementType = driver.scenario.localized.movement.get_type_py() \n
		No command help available \n
			:return: type_py: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.MovementType)

	def set_type_py(self, type_py: enums.MovementType) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:TYPE \n
		Snippet: driver.scenario.localized.movement.set_type_py(type_py = enums.MovementType.ARC) \n
		No command help available \n
			:param type_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.MovementType)
		self._core.io.write(f'SCENario:LOCalized:MOVement:TYPE {param}')

	# noinspection PyTypeChecker
	def get_vehicle(self) -> enums.VehicleMovement:
		"""SCPI: SCENario:LOCalized:MOVement:VEHicle \n
		Snippet: value: enums.VehicleMovement = driver.scenario.localized.movement.get_vehicle() \n
		No command help available \n
			:return: vehicle: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:VEHicle?')
		return Conversions.str_to_scalar_enum(response, enums.VehicleMovement)

	def set_vehicle(self, vehicle: enums.VehicleMovement) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:VEHicle \n
		Snippet: driver.scenario.localized.movement.set_vehicle(vehicle = enums.VehicleMovement.AIRPlane) \n
		No command help available \n
			:param vehicle: No help available
		"""
		param = Conversions.enum_scalar_to_str(vehicle, enums.VehicleMovement)
		self._core.io.write(f'SCENario:LOCalized:MOVement:VEHicle {param}')

	def get_waypoint(self) -> str:
		"""SCPI: SCENario:LOCalized:MOVement:WAYPoint \n
		Snippet: value: str = driver.scenario.localized.movement.get_waypoint() \n
		No command help available \n
			:return: waypoint: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:WAYPoint?')
		return trim_str_response(response)

	def set_waypoint(self, waypoint: str) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:WAYPoint \n
		Snippet: driver.scenario.localized.movement.set_waypoint(waypoint = '1') \n
		No command help available \n
			:param waypoint: No help available
		"""
		param = Conversions.value_to_quoted_str(waypoint)
		self._core.io.write(f'SCENario:LOCalized:MOVement:WAYPoint {param}')

	def get_yaw(self) -> float:
		"""SCPI: SCENario:LOCalized:MOVement:YAW \n
		Snippet: value: float = driver.scenario.localized.movement.get_yaw() \n
		No command help available \n
			:return: yaw: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MOVement:YAW?')
		return Conversions.str_to_float(response)

	def set_yaw(self, yaw: float) -> None:
		"""SCPI: SCENario:LOCalized:MOVement:YAW \n
		Snippet: driver.scenario.localized.movement.set_yaw(yaw = 1.0) \n
		No command help available \n
			:param yaw: No help available
		"""
		param = Conversions.decimal_value_to_str(yaw)
		self._core.io.write(f'SCENario:LOCalized:MOVement:YAW {param}')

	def clone(self) -> 'Movement':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Movement(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
